==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Components/Controls/Dateboxes/Base/Date.js <==
import Control from "../../Control";

class Datetimebox extends Control {

    constructor(name) {
        super(name)

        this.label = 'My Label (' + this.name + ')'
        this.placeholder = 'My placeholder (' + this.name + ')'

        this.todayHighlight = true
        this.orientation = "bottom right"
        this.templates = {
            leftArrow: '<i class="la la-angle-left"></i>',
            rightArrow: '<i class="la la-angle-right"></i>'
        }

        this.todayBtn = "linked"
        this.clearBtn = true
        this.autoclose = true
        // this.showMeridian = false
        // this.format = 'dd.mm.yyyy hh:ii'
        // this.pickerPosition = 'top-left'
        // this.startView =2 
        // this.minView = 0
        // this.maxView = 4
        // this.forceParse = false
        // this.weekStart = 1
        // this.minuteStep = 1

        this.momentFormat = 'DD.MM.YYYY'
        this.mysqlFormat = 'YYYY-MM-DD'

        this.vue = null

        this.plugin = null
    }

    SetPlaceholder(value) {
        this.placeholder = value
        return this
    }

    SetLabel(value) {
        this.label = value
        return this
    }

    SetOrientation(value) {
        this.orientation = value
        return this        
    }

    get pluginOptions() {
        let r = {
            todayHighlight: this.todayHighlight,
            orientation: this.orientation,
            templates: this.templates,
            todayBtn: this.todayBtn,
            clearBtn: this.clearBtn,
            autoclose: this.autoclose,
            // format: this.format,
            // pickerPosition: this.pickerPosition,
            // showMeridian: this.showMeridian,
            // startView: this.startView,
            // minView: this.minView,
            // maxView: this.maxView,
            // forceParse: this.forceParse,
            // weekStart: this.weekStart,
            // minuteStep: this.minuteStep,
        }
        return r
    }

    Value(value) {
        return value ? moment(value, this.mysqlFormat).format(this.momentFormat) : null
    }

    CreatePlugin(vue) {
        this.vue = vue
        let self = this, i = setInterval( () => {
            let jq = $('#input-' + this.id)
            if(jq.length == 1)
            {
                clearInterval(i)
                this.instance = jq.datepicker(this.pluginOptions)
                this.instance.on('changeDate', function(e) {
                    vue.$emit('input', moment(e.date).format(self.mysqlFormat))
                })
            }
        }, 100)
    }

}

export default Datetimebox

==> comptechsoft-vue-foundation-1.0.12.tgz: package/src/~compvuetech/Components/Controls/Dateboxes/Base/Date.js <==
import Control from "../../Control";

class Datetimebox extends Control {

    constructor(name) {
        super(name)

        this.label = 'My Label (' + this.name + ')'
        this.placeholder = 'My placeholder (' + this.name + ')'

        this.todayHighlight = true
        this.orientation = "bottom right"
        this.templates = {
            leftArrow: '<i class="la la-angle-left"></i>',
            rightArrow: '<i class="la la-angle-right"></i>'
        }

        this.todayBtn = "linked"
        this.clearBtn = true
        this.autoclose = true
        // this.showMeridian = false
        this.format = 'dd.mm.yyyy'
        // this.pickerPosition = 'top-left'
        // this.startView =2 
        // this.minView = 0
        // this.maxView = 4
        // this.forceParse = false
        // this.weekStart = 1
        // this.minuteStep = 1

        this.momentFormat = 'DD.MM.YYYY'
        this.mysqlFormat = 'YYYY-MM-DD'

        this.vue = null

        this.plugin = null
    }

    SetPlaceholder(value) {
        this.placeholder = value
        return this
    }

    SetLabel(value) {
        this.label = value
        return this
    }

    SetOrientation(value) {
        this.orientation = value
        return this        
    }

    get pluginOptions() {
        let r = {
            todayHighlight: this.todayHighlight,
            orientation: this.orientation,
            templates: this.templates,
            todayBtn: this.todayBtn,
            clearBtn: this.clearBtn,
            autoclose: this.autoclose,
            format: this.format,
            // pickerPosition: this.pickerPosition,
            // showMeridian: this.showMeridian,
            // startView: this.startView,
            // minView: this.minView,
            // maxView: this.maxView,
            // forceParse: this.forceParse,
            // weekStart: this.weekStart,
            // minuteStep: this.minuteStep,
        }
        return r
    }

    Value(value) {
        return value ? moment(value, this.mysqlFormat).format(this.momentFormat) : null
    }

    CreatePlugin(vue) {
        this.vue = vue
        let self = this, i = setInterval( () => {
            let jq = $('#input-' + this.id)
            if(jq.length == 1)
            {
                clearInterval(i)
                this.instance = jq.datepicker(this.pluginOptions)
                this.instance.on('changeDate', function(e) {
                    vue.$emit('input', moment(e.date).format(self.mysqlFormat))
                })
            }
        }, 100)
    }

}

export default Datetimebox
